import datetime
import os
import psutil
from django.template.defaultfilters import slugify

class BigBrotherModule():
    name = 'Unamed'
    write_to_db = True
    prepend_text = ''
    add_text = ''
    
    def get_val(self):
        return None
        
    def get_text(self):
        return '%s%s%s' % (self.prepend_text, self.get_val(), self.add_text)
        
    def get_slug(self):
        return slugify(self.name)

class UserCount(BigBrotherModule):
    name = 'Total Users'
    
    def get_val(self):
        from django.contrib.auth.models import User
        users = User.objects.all()
        return users.count()

        
class NewUsersTodayCount(BigBrotherModule):
    name = 'New Users Today'
    
    def get_val(self):
        from django.contrib.auth.models import User
        curday = datetime.datetime.today()
        users = User.objects.filter(date_joined__year=curday.year, date_joined__month=curday.month, date_joined__day=curday.day)
        return users.count()


class FreeRamCount(BigBrotherModule):
    name = 'Free RAM'
    add_text = ' MB'
    
    def get_val(self):
        return str(psutil.avail_phymem() / (1024 * 1024))


class FreeDiskCount(BigBrotherModule):
    name = 'Free Disk Space'
    add_text = ' GB'
    
    def get_val(self):
        s = os.statvfs('/')
        return str(round((s.f_bavail * s.f_frsize) / ( 1024 * 1024 * 1024.0 ), 1))



from django.conf import settings
from django.conf.urls.defaults import *

urlpatterns = patterns('',
    url('^$', 'bigbrother.views.index', name='bigbrother_index'),
    url('^graph/(?P<slug>[^/]+)/$', 'bigbrother.views.graph', name='bigbrother_graph'),
    url('^update/$', 'bigbrother.views.update', name='bigbrother_update'),
)


# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Changing field 'ModuleStat.value'
        db.alter_column('bigbrother_modulestat', 'value', self.gf('django.db.models.fields.DecimalField')(max_digits=10, decimal_places=2))


    def backwards(self, orm):
        
        # Changing field 'ModuleStat.value'
        db.alter_column('bigbrother_modulestat', 'value', self.gf('django.db.models.fields.IntegerField')())


    models = {
        'bigbrother.modulestat': {
            'Meta': {'object_name': 'ModuleStat'},
            'added': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modulename': ('django.db.models.fields.CharField', [], {'max_length': '64'}),
            'value': ('django.db.models.fields.DecimalField', [], {'max_digits': '10', 'decimal_places': '2'})
        }
    }

    complete_apps = ['bigbrother']



#!/usr/bin/env python
from setuptools import setup,find_packages

METADATA = dict(
    name='django-bigbrother',
    version='0.2.0',
    author='Anders Petersson',
    author_email='me@anderspetersson.se',
    description='Modular Dashboard for Django Projects',
    long_description='Django-Bigbrother is a reusable, modular, dashboard for Django Projects. Designed to be easy to extend.',
    url='http://github.com/anderspetersson/django-bigbrother',
    keywords='django dashboard bigbrother monitoring',
    install_requires=['psutil'],
    include_package_data=True,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Monitoring',
        'Environment :: Web Environment',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
    zip_safe = False,
    packages=find_packages(),
    package_data={'bigbrother': ['templates/bigbrother/*.html', 'static/css/*', 'static/img/*'], }
)

if __name__ == '__main__':
    setup(**METADATA)



from django.conf import settings
from django.utils.importlib import import_module
from django.http import HttpResponse
from django.shortcuts import render_to_response
from django.template import RequestContext

from bigbrother.models import ModuleStat


def index(request):
    
    bb = []

    for m in settings.BIGBROTHER_MODULES:
        modulename, attr = m.rsplit('.', 1)
        module = import_module(modulename)
        name = getattr(module,attr)().name
        value = getattr(module,attr)().get_text()
        bb.append({'name':name, 'value':value})
    
    return render_to_response('bigbrother/index.html', {'bb': bb}, context_instance=RequestContext(request)) 

def graph(request, slug):
    stats = ModuleStat.objects.filter(modulename=slug)[0:30]    
    return render_to_response('bigbrother/graph.html', {'stats': stats}, context_instance=RequestContext(request))

def update(request):
    
    bb = []
    
    for m in settings.BIGBROTHER_MODULES:
        modulename, attr = m.rsplit('.', 1)
        module = import_module(modulename)
        
        if getattr(module,attr)().write_to_db:
            name = getattr(module,attr)().get_slug()
            value = getattr(module,attr)().get_val()
            bb.append({'name':name, 'value':value})
            
    for mo in bb:
        ModuleStat(modulename=mo['name'], value=mo['value']).save()
    
    return HttpResponse(bb)
            

    
